<?

require('./include/conf.php.inc');
require('./include/index.php.inc');

echo '<?xml version="1.0" encoding="ISO-8859-15"?>';

?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="nl">
	<head>
		<title>http://<?=$title?></title>
		<meta name="author" content="<?=XPindex_Author?>" />
		<meta name="date" content="<?=XPindex_Date?>" />
		<meta name="description" content="XPindex <?=XPindex_Version?> by <?=XPindex_Author?>"?>
		<meta name="url" content="<?=XPindex_URL?>"?>
		<link rel="icon" href="<?=$XPIndexConf['Web Directory'] . '/icons/map.png'?>" type="image/png" />
		<link rel="shortcut icon" href="<?=$XPIndexConf['Web Directory'] . '/icons/map.ico'?>" />
		<style type="text/css">
			@import url(<?=$XPIndexConf['Web Directory']?>/css/index.php);
		</style>
	</head>
	<body>
		<div style="position: absolute; top: 0px; left: 0px;height: 100%">
			<table cellspacing="0" cellpadding="0" class="main">
				<tr>
<?DrawTaskBar($Directory)?>
					<td style="width: 100%; vertical-align: top; padding: 0px; height: 100%">
						<table cellspacing="0" cellpadding="0" class="header-<?=$XPIndexConf['Theme']?>">
							<thead>
								<tr>
									<th class="header-left-<?=$XPIndexConf['Theme']?>">
										<a href="<?=$RequestURI?>?sort=name" class="head"><?=$Captions['filename'][$XPIndexConf['Language']]?></a></th>
									<th class="header-right-<?=$XPIndexConf['Theme']?>">
										<a href="<?=$RequestURI?>?sort=size" class="head"><?=$Captions['size'][$XPIndexConf['Language']]?></a></th>
									<th class="header-left-<?=$XPIndexConf['Theme']?>">
										<a href="<?=$RequestURI?>?sort=type" class="head"><?=$Captions['type'][$XPIndexConf['Language']]?></a></th>
									<th class="header-left-<?=$XPIndexConf['Theme']?>">
										<a href="<?=$RequestURI?>?sort=modify" class="head"><?=$Captions['changed'][$XPIndexConf['Language']]?></a></th>
									<th class="header-left-<?=$XPIndexConf['Theme']?>">
										<a href="<?=$RequestURI?>?sort=owner" class="head"><?=$Captions['owner'][$XPIndexConf['Language']]?></a></th>
									<th class="header-left-<?=$XPIndexConf['Theme']?>">
										<a href="<?=$RequestURI?>?sort=group" class="head"><?=$Captions['group'][$XPIndexConf['Language']]?></a></th>
									<th class="header-left-<?=$XPIndexConf['Theme']?>">
										<a href="<?=$RequestURI?>?sort=permission" class="head"><?=$Captions['attributes'][$XPIndexConf['Language']]?></a></th>
									<th class="fill">&nbsp;</th>
								</tr>
							</thead>
							<tbody>
<?ParseDir($Directory)?>
							</tbody>
						</table>
					</td>
				</tr>
<?DrawStatusBar()?>
			</table>
		</div>
	</body>
</html>
