<?php

$XPIndexConf = array();
$ApacheConf = array();

// Web Directory:
// Relative position to the webroot
$XPIndexConf['Web Directory'] = '/XPindex';

// Hide XPindex Dir
// If true the server will return a 404 code if the request is in the webdirectory specified by $XPIndexConf['Web Directory']
$XPIndexConf['Hide XPindex Dir'] = false;

// Theme:
// default, olive, silver
$XPIndexConf['Theme'] = 'default';

// TaskBar
// never = never draw the taskbar
// readme = only draw the taskbar when there is an README.html file in the directory
// always = always draw the taskbar
$XPIndexConf['TaskBar'] = 'readme';

// Language:
// nl = Dutch
// en = English
$XPIndexConf['Language'] = 'nl';

// User Directories:
// The directory where the userdirs are created (default: /home).
$ApacheConf['User Directories'] = '/home';

// User HTML Directory:
// This is the same entry as can be found in the apache config file (default: public_html).
$ApacheConf['User HTML Directory'] = 'public_html';

// Readme Files:
// This is the same entry as can be found in the apache config file (default: README.html).
$ApacheConf['Readme Files'] = Array(
//	'Filename'			Type,		Show,	$Caption[]
	'README.html' => Array(RF_HTML,	false, 	'readme'),
	'file_id.diz' => Array(RF_TEXT,	true, 	'file_id.diz')
);


// File descriptions:
$FileExtensions = Array(
	'Directory Up'	=> Array(
		'nl' => 'Bovenliggende map',
		'en' => 'Parent folder'),
	'Directory'	=> Array(
		'nl' => 'Map',
		'en' => 'Folder'),
	'asf' => Array(
		'nl' => 'Windows Media Audio/Video-bestand',
		'en' => 'Windows Media Audio/Video File'),
	'avi' => Array(
		'nl' => 'Video Clip',
		'en' => 'Video Clip'),
	'bmp' => Array(
		'nl' => 'Bitmapafbeelding',
		'en' => 'Bitmap Image'),
	'config' => Array(
		'nl' => 'Web Configuratie-bestand',
		'en' => 'Web Configuration File'),
	'css' => Array(
		'nl' => 'Document met trapgewijs opmaakmodel',
		'en' => 'CSS File'),
	'db' => Array(
		'nl' => 'Databasebestand',
		'en' => 'DBase File'),
	'dll' => Array(
		'nl' => 'Toepassingsuitbreiding',
		'en' => 'Application Extension'),
	'doc' => Array(
		'nl' => 'Microsoft Word-document',
		'en' => 'Microsoft Word-document'),
	'exe' => Array(
		'nl' => 'Toepassing',
		'en' => 'Application'),
	'gif' => Array(
		'nl' => 'GIF-afbeelding',
		'en' => 'GIF Image'),
	'gz' => Array(
		'nl' => 'GZip-archief',
		'en' => 'GZip Archive'),
	'htm' => Array(
		'nl' => 'HTML-document',
		'en' => 'HTML Document'),
	'html' => Array(
		'nl' => 'HTML-document',
		'en' => 'HTML Document'),
	'ini' => Array(
		'nl' => 'Configuratie-instellingen',
		'en' => 'Configuratie Settings'),
	'jpg' => Array(
		'nl' => 'JPEG-afbeelding',
		'en' => 'JPEG Image'),
	'jpeg' => Array(
		'nl' => 'JPEG-afbeelding',
		'en' => 'JPEG Image'),
	'js' => Array(
		'nl' => 'JScript Script-bestand',
		'en' => 'JScript Script File'),
	'jse' => Array(
		'nl' => 'JScript encoded Script-bestand',
		'en' => 'JScript encoded Script File'),
	'mp3' => Array(
		'nl' => 'MP3 media-bestand',
		'en' => 'MP3 Media File'),
	'mpe' => Array(
		'nl' => 'Film-bestand',
		'en' => 'Movie File'),
	'mpeg' => Array(
		'nl' => 'Film-bestand',
		'en' => 'Movie File'),
	'mpg' => Array(
		'nl' => 'Film-bestand',
		'en' => 'Movie File'),
	'ocx' => Array(
		'nl' => 'ActiveX-besturingselement',
		'en' => 'ActiveX Control'),
	'pdf' => Array(
		'nl' => 'Adobe Acrobat Document',
		'en' => 'Adobe Acrobat Document'),
	'php' => Array(
		'nl' => 'PHP Script-bestand',
		'en' => 'PHP Script File'),
	'php3' => Array(
		'nl' => 'PHP3 Script-bestand',
		'en' => 'PHP3 Script File'),
	'php4' => Array(
		'nl' => 'PHP4 Script-bestand',
		'en' => 'PHP4 Script File'),
	'phps' => Array(
		'nl' => 'PHP Script Source-bestand',
		'en' => 'PHP Script Source File'),
	'phtml' => Array(
		'nl' => 'PHP Script-bestand',
		'en' => 'PHP Script File'),
	'png' => Array(
		'nl' => 'PNG-afbeelding',
		'en' => 'PNG Image'),
	'rar' => Array(
		'nl' => 'WinRAR-archief',
		'en' => 'WinRAR Archive'),
	'rc' => Array(
		'nl' => 'Resource Script',
		'en' => 'Resource Script'),
	'sql' => Array(
		'nl' => 'SQL Script-bestand',
		'en' => 'SQL Script File'),
	'tar' => Array(
		'nl' => 'Tarball-archief',
		'en' => 'Tarball Archive'),
	'tgz' => Array(
		'nl' => 'GZip Tarball-archief',
		'en' => 'GZip Tarball Archive'),
	'txt' => Array(
		'nl' => 'Tekstdocument',
		'en' => 'TXT File'),
	'xls' => Array(
		'nl' => 'Microsoft Excel-werkblad',
		'en' => 'Microsoft Excel-sheet'),
	'xml' => Array(
		'nl' => 'XML-document',
		'en' => 'XML Document'),
	'xsl' => Array(
		'nl' => 'XSL-opmaakmodel',
		'en' => 'XSL Document'),
	'xslt' => Array(
		'nl' => 'XSL Transformation',
		'en' => 'XSL Transformation'),
	'zip' => Array(
		'nl' => 'Gecomprimeerde map',
		'en' => 'Compressed folder')
);

$IncrementalFileExtensions = Array(
	'r' => 'rar'
);

//	File icons:
$FileIcons = Array(
	'Refresh' => 'refresh.png',
	'Directory Up' => 'mapup.png',
	'Directory' => 'map.png',
	'asf' => 'avi.png',
	'avi' => 'avi.png',
	'bmp' => 'bmp.png',
	'config' => 'config.png',
	'css' => 'ini.png',
	'db' => 'dll.png',
	'diz' => 'txt.png',
	'dll' => 'dll.png',
	'gz' => 'zip.png',
	'gif' => 'gif.png',
	'html' => 'html.png',
	'htm' => 'html.png',
	'ini' => 'ini.png',
	'jpg' => 'jpg.png',
	'jpeg' => 'jpg.png',
	'js' => 'js.png',
	'jse' => 'js.png',
	'local' => 'dll.png',
	'mp3' => 'mp3.png',
	'mpe' => 'avi.png',
	'mpeg' => 'avi.png',
	'mpg' => 'avi.png',
	'ocx' => 'dll.png',
	'pdf' => 'pdf.png',
	'php' => 'php.png',
	'php3' => 'php.png',
	'php4' => 'php.png',
	'phps' => 'php.png',
	'phtml' => 'php.png',
	'png' => 'gif.png',
	'rar' => 'rar.png',
	'rc' => 'rc.png',
	'shtm' => 'html.png',
	'shtml' => 'html.png',
	'sql' => 'sql.png',
	'tar' => 'zip.png',
	'tgz' => 'zip.png',
	'txt' => 'txt.png',
	'xls' => 'xls.png',
	'xml' => 'xml.png',
	'xsl' => 'xsl.png',
	'xslt' => 'xslt.png',
	'zip' => 'zip.png'
);

$Captions = Array(
	'file' => Array(
		'nl' => 'bestand',
		'en' => 'file'),
	'filename' => Array(
		'nl' => 'Naam',
		'en' => 'Filename'),
	'size' => Array(
		'nl' => 'Grootte',
		'en' => 'Size'),
	'type' => Array(
		'nl' => 'Type',
		'en' => 'Type'),
	'changed' => Array(
		'nl' => 'Gewijzigd op',
		'en' => 'Changed at'),
	'owner' => Array(
		'nl' => 'Eigenaar',
		'en' => 'Owner'),
	'group' => Array(
		'nl' => 'Groep',
		'en' => 'Group'),
	'attributes' => Array(
		'nl' => 'Kenmerken',
		'en' => 'Attributes'),
	'changed' => Array(
		'nl' => 'Gewijzigd op',
		'en' => 'Changed at'),
	'readme' => Array(
		'nl' => 'Readme',
		'en' => 'Readme'),
	'objects' => Array(
		'nl' => 'objecten',
		'en' => 'objects'),
	'file_id.diz' => Array(
		'nl' => 'file_id.diz',
		'en' => 'file_id.diz')
);

$FileSizeGroups = Array(
	1 => Array(
		'nl' => 'Nul',
		'en' => 'Zero'),
	2 => Array(
		'nl' => 'Zeer Klein',
		'en' => 'Tiny'),
	3 => Array(
		'nl' => 'Klein',
		'en' => 'Small'),
	4 => Array(
		'nl' => 'Normaal',
		'en' => 'Normal'),
	5 => Array(
		'nl' => 'Groot',
		'en' => 'Large'),
	6 => Array(
		'nl' => 'Zeer Groot',
		'en' => 'Very Large'),
	7 => Array(
		'nl' => 'Gigantisch Groot',
		'en' => 'Extreme Large'),
	9 => Array(
		'nl' => 'Map',
		'en' => 'Directory')
);

$FileDateGroups = Array(
	'01' => Array(
		'nl' => 'Vandaag',
		'en' => 'Today'),
	'02' => Array(
		'nl' => 'Gisteren',
		'en' => 'Yesterday'),
	'03' => Array(
		'nl' => 'Eerder deze week',
		'en' => 'Earlier this week'),
	'04' => Array(
		'nl' => 'Vorige week',
		'en' => 'Last Week'),
	'05' => Array(
		'nl' => 'Twee weken geleden',
		'en' => 'Two weeks ago'),
	'06' => Array(
		'nl' => 'Eerder deze maand',
		'en' => 'Earlier this month'),
	'07' => Array(
		'nl' => 'Afgelopen maand',
		'en' => 'Last Month'),
	'08' => Array(
		'nl' => 'Twee maanden geleden',
		'en' => 'Two months ago'),
	'09' => Array(
		'nl' => 'Eerder dit jaar',
		'en' => 'Earlier this year'),
	'10' => Array(
		'nl' => 'Vorig jaar',
		'en' => 'Last Year'),
	'11' => Array(
		'nl' => 'Twee jaar geleden',
		'en' => 'Two years ago'),
	'12' => Array(
		'nl' => 'Lang geleden',
		'en' => 'Long time ago'),
	'13' => Array(
		'nl' => 'Morgen',
		'en' => 'Tomorrow'),
	'14' => Array(
		'nl' => 'Over twee dagen',
		'en' => 'Within two days'),
	'15' => Array(
		'nl' => 'Later deze week',
		'en' => 'Later this week'),
	'16' => Array(
		'nl' => 'Later deze maand',
		'en' => 'Later this month'),
	'17' => Array(
		'nl' => 'Volgende maand',
		'en' => 'Next month'),
	'18' => Array(
		'nl' => 'Later dit jaar',
		'en' => 'Later this year'),
	'19' => Array(
		'nl' => 'Volgend jaar',
		'en' => 'Next year'),
	'20' => Array(
		'nl' => 'Over twee jaar',
		'en' => 'Within two years'),
	'21' => Array(
		'nl' => 'Verder in de toekomst',
		'en' => 'Further in the future')
);

?>